<?xml version="1.0" encoding="utf-8"?>
<rss version="2.0" xml:base="http://www.802automation.com/ws" xmlns:dc="http://purl.org/dc/elements/1.1/">
<channel>
 <title>802automation.com - 802anonymous</title>
 <link>http://www.802automation.com/ws/taxonomy/term/35/0</link>
 <description>Acces for anyone - a logon is not required</description>
 <language>en</language>
<item>
 <title>IMS - qkuro - Backing up files</title>
 <link>http://www.802automation.com/ws/Backing_up_qkuro_files</link>
 <description> &lt;H2&gt;IMS - qkuro - Backing up files&lt;/H2&gt;

The code snippets shown below are for demonstration purposes only and should only be used by qualified personnel. (Microsoft Windows Vista - see note below.)

&lt;p&gt;
The qkuro contains four files which determine the pages shown on the Web pages and the data sent over ftp and shown in the Energy Profile.
&lt;/p&gt;

&lt;pre&gt;
       dir.txt         a directory listing      read only
       clone.icf       the IP configuration     read/write
       log.csv         the entire datalog file  read only
       webpages.fat    all the individual       read/write
                       webpages as one file
&lt;/pre&gt;

Access to the files is through tftp&lt;a href=&quot;/ws/glossary#term57&quot; title=&quot;tftp: Trivial File Transfer Protocol (TFTP) is a very simple file transfer protocol, 
  with the functionality of a very basic form of FTP; it was first defined in 
  1980.
 Some details of TFTP: 
 * It uses UDP (port 69) as its transport protocol (unlike FTP which uses TCP 
  port 21).
  * It cannot list directory contents.
  * It has no authentication or encryption mechanisms.
  * It is used to read files from, or write files to, a remote server.
  * It supports three different transfer modes, &amp;amp;quot;netascii&amp;amp;quot;, &amp;amp;quot;octet&amp;amp;quot; 
  and &amp;amp;quot;mail&amp;amp;quot;, with the first two corresponding to the &amp;amp;quot;ASCII&amp;amp;quot; 
  and &amp;amp;quot;image&amp;amp;quot; (binary) modes of the FTP protocol; the third is now obsolete 
  and is hardly ever used.
  * It has a file size limit of 32 MB.
Due to the lack of security, it is dangerous over the open Internet. Thus, 
  TFTP is generally only used on private, local networks.
Example command in tftp in Windows Transfers files to and from a remote 
  computer running the TFTP service.
TFTP [-i] host [GET | PUT] source [destination]
 -i Specifies binary image transfer mode (also called octet). 
  In binary image mode the file is moved literally, byte by byte. Use this mode 
  when transferring binary files.
  host Specifies the local or remote host.
  GET Transfers the file destination on the remote host to the 
  file source on the local host.
  PUT Transfers the file source on the local host to the file 
  destination on the remote host.
  source Specifies the file to transfer.
  destination Specifies where to transfer the file.

&quot; class=&quot;glossary-indicator&quot;&gt;i&lt;/a&gt; and a command can be carried out by creating a single line file with a .bat extension. Vista users will have to ensure that the tftp, which is always included as a standard feature, is enabled.

&lt;pre&gt;
tftp -i 192.168.1.127 GET dir.txt dir.txt 
&lt;/PRE&gt;

This will GET the clone file from a qkuro with an IP address of 192.168.1.127 and create a read only file in the same directory called clone.icf. (Tftp uses port 69 so can normally only be used locally thus preventing any unauthorised remote access to these files. The port can be deliberately opened with port forwarding or a DMZ.) 

Adding pause to the file then enables you to check that the command completed successfully before acknowledging it and closing the command window.

&lt;pre&gt;
tftp -i 192.168.1.127 GET dir.txt dir.txt 
pause
&lt;/PRE&gt;

All four files can be saved by including the four tftp GET commands in one file.

&lt;pre&gt;
tftp -i 192.168.1.127 GET dir.txt dir.txt 
tftp -i 192.168.1.127 GET log.csv log.csv
tftp -i 192.168.1.127 GET webpages.fat webpages.fat
tftp -i 192.168.1.127 GET clone.icf clone.icf
pause
&lt;/PRE&gt;

As the files are read only this will not normally overwrite earlier files.


&lt;H3&gt;Advanced&lt;/H3&gt;

The sample code shown below creates file names which include the IP address and the local time and date. This enables better records to be maintained and files are unlikely to be overwritten.

&lt;pre&gt;

set WP_defaultIP=192.168.1.127

for /F &quot;tokens=1-4 delims=/:., &quot; %%a in (&#039;date/T&#039;) do set f_name=%%c%%b%%a
for /F &quot;tokens=1-2 delims=:., &quot; %%a in (&#039;time/T&#039;) do set f_name=%f_name%_%%a%%b
tftp -i %WP_defaultIP% GET dir.txt __%WP_defaultIP%_%f_name%_dir.txt 
rem notepad __%WP_defaultIP%_%f_name%_dir.txt  


for /F &quot;tokens=1-4 delims=/:., &quot; %%a in (&#039;date/T&#039;) do set f_name=%%c%%b%%a
for /F &quot;tokens=1-2 delims=:., &quot; %%a in (&#039;time/T&#039;) do set f_name=%f_name%_%%a%%b
tftp -i %WP_defaultIP% GET clone.icf __%WP_defaultIP%_%f_name%_clone.icf
copy  __%WP_defaultIP%_%f_name%_clone.icf __%WP_defaultIP%_clone.icf
rem notepad __%WP_defaultIP%_%f_name%_clone.icf  

for /F &quot;tokens=1-4 delims=/:., &quot; %%a in (&#039;date/T&#039;) do set f_name=%%c%%b%%a
for /F &quot;tokens=1-2 delims=:., &quot; %%a in (&#039;time/T&#039;) do set f_name=%f_name%_%%a%%b
tftp -i %WP_defaultIP% GET log.csv __%WP_defaultIP%_%f_name%_log.csv 
rem notepad __%WP_defaultIP%_%f_name%_log.csv  

for /F &quot;tokens=1-4 delims=/:., &quot; %%a in (&#039;date/T&#039;) do set f_name=%%c%%b%%a
for /F &quot;tokens=1-2 delims=:., &quot; %%a in (&#039;time/T&#039;) do set f_name=%f_name%_%%a%%b
tftp -i %WP_defaultIP% GET webpages.fat __%WP_defaultIP%_%f_name%_webpages.fat 
rem notepad __%WP_defaultIP%_%f_name%_webpages.fat  

pause

&lt;/pre&gt;

&lt;p&gt;
Note.
&lt;BR&gt;
Microsoft Windows Vista.
&lt;BR&gt;
tftp may need to be enabled - see http://windowshelp.microsoft.com/Windows/en-US/Help/1e62706b-ef53-4ecd-a217-0e7bcf82009b1033.mspx 
&lt;/p&gt; </description>
 <comments>http://www.802automation.com/ws/Backing_up_qkuro_files#comment</comments>
 <category domain="http://www.802automation.com/ws/taxonomy/term/35">802anonymous</category>
 <pubDate>Thu, 24 Jan 2013 11:29:05 +0000</pubDate>
 <dc:creator>Paul</dc:creator>
 <guid isPermaLink="false">127 at http://www.802automation.com/ws</guid>
</item>
<item>
 <title>IMS - qkuro - setting the network address</title>
 <link>http://www.802automation.com/ws/IMSqkurosettingthenetworkaddress</link>
 <description> &lt;p&gt;&lt;strong&gt;&amp;nbsp;&lt;/strong&gt;&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;IMS - qkuro  Ethernet&lt;a href=&quot;/ws/glossary#term86&quot; title=&quot;Ethernet: The most widely used local area network (LAN) access method, defined by the IEEE as the 802.3 standard. Ethernet has become so popular that a specification for &amp;quot;LAN connection&amp;quot; or &amp;quot;network card&amp;quot; implies Ethernet without saying so. Ethernet allows connection to a company or home network as well as to a cable modem or DSL modem for Internet access.

Almost all PCs and Macs are fitted with 10/100 Ethernet ports which connect internally to a network adapter (NIC) that is typically built onto the motherboard.&quot; class=&quot;glossary-indicator&quot;&gt;i&lt;/a&gt; Option - Installation&lt;/strong&gt;&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;Before you begin&lt;/strong&gt;&lt;br /&gt;
  Please ask your network administrator to complete the table below.&lt;/p&gt;
&lt;table border=&quot;0&quot; cellspacing=&quot;0&quot; cellpadding=&quot;0&quot;&gt;
 &lt;tr&gt;
    &lt;td width=&quot;143&quot;&gt;&lt;/td&gt;
    &lt;td width=&quot;343&quot;&gt;&lt;/td&gt;
    &lt;td width=&quot;43&quot;&gt;&lt;/td&gt;
  &lt;/tr&gt;

  &lt;tr&gt;
    &lt;td colspan=&quot;2&quot;&gt;&lt;p&gt;&lt;strong&gt;IMS - qkuro  settings required. &lt;/strong&gt; &lt;/p&gt;&lt;/td&gt;
    &lt;td&gt;&lt;p align=&quot;center&quot;&gt;Notes.&lt;/p&gt;&lt;/td&gt;
  &lt;/tr&gt;

  &lt;tr&gt;
    &lt;td align=&quot;right&quot;&gt;Static IP Address&lt;/td&gt;
    &lt;td style=&quot;font-size:14.0pt;&quot;&gt;[][][].[][][].[][][].[][][]&lt;/td&gt;
	&lt;td align=&quot;center&quot;&gt;&amp;nbsp;&lt;/td&gt;
  &lt;/tr&gt;

  &lt;tr&gt;
    &lt;td align=&quot;right&quot;&gt;Subnet Mask&lt;/td&gt;
    &lt;td style=&quot;font-size:14.0pt;&quot;&gt;[][][].[][][].[][][].[][][]&lt;/td&gt;
	&lt;td&gt;&lt;/td&gt;
  &lt;/tr&gt;
  &lt;tr&gt;
    &lt;td&gt;&lt;p&gt;&amp;nbsp;&lt;/p&gt; &lt;p&gt;&lt;a href=&quot;http://www.802automation.com/ws/IMSqkurosettingthenetworkaddress&quot;&gt;read more&lt;/a&gt;&lt;/p&gt;</description>
 <comments>http://www.802automation.com/ws/IMSqkurosettingthenetworkaddress#comment</comments>
 <category domain="http://www.802automation.com/ws/taxonomy/term/35">802anonymous</category>
 <pubDate>Wed, 14 Sep 2011 18:25:27 +0100</pubDate>
 <dc:creator>Paul</dc:creator>
 <guid isPermaLink="false">126 at http://www.802automation.com/ws</guid>
</item>
<item>
 <title>IMS - Datalogging - File size and content</title>
 <link>http://www.802automation.com/ws/IMSdataloggingfiles</link>
 <description> &lt;H3&gt;IMS - Datalogging - File size and content &lt;/H3&gt;
&lt;p&gt;During a machine cycle, files containing a header and data are sent at regular intervals to the ftp server.
&lt;BR&gt;
 Between cycles, a file containing just a header is sent at the same time interval to act as a watchdog 
 and confirm that the network is fuctional.

&lt;BR&gt; 
Typical settings and data rates are shown below. 
&lt;pre&gt;&lt;B&gt;Machine type            Washer/Disinfector        Autoclave/Steriliser &lt;/B&gt;				
Typical cycle time      45 to 90 mins             20 to 45 mins
datalog interval        5 seconds                 1 second
ftp interval            5 minutes                 1 minute		
 &lt;p&gt;&lt;a href=&quot;http://www.802automation.com/ws/IMSdataloggingfiles&quot;&gt;read more&lt;/a&gt;&lt;/p&gt;</description>
 <comments>http://www.802automation.com/ws/IMSdataloggingfiles#comment</comments>
 <category domain="http://www.802automation.com/ws/taxonomy/term/35">802anonymous</category>
 <pubDate>Wed, 14 Sep 2011 13:34:57 +0100</pubDate>
 <dc:creator>Paul</dc:creator>
 <guid isPermaLink="false">125 at http://www.802automation.com/ws</guid>
</item>
<item>
 <title>IMS</title>
 <link>http://www.802automation.com/ws/IMShead</link>
 <description> IMS - details </description>
 <comments>http://www.802automation.com/ws/IMShead#comment</comments>
 <category domain="http://www.802automation.com/ws/taxonomy/term/35">802anonymous</category>
 <pubDate>Wed, 14 Sep 2011 13:32:37 +0100</pubDate>
 <dc:creator>Paul</dc:creator>
 <guid isPermaLink="false">124 at http://www.802automation.com/ws</guid>
</item>
<item>
 <title>CubeIP - Data Logging memory</title>
 <link>http://www.802automation.com/ws/Data_Logging_memory</link>
 <description> &lt;h2&gt;Data Logging memory&lt;/H2&gt;
&lt;P&gt;
The CubeIP meter has sufficient non-volatile memory to store over
20,000 records of kwh and kvarh. This will use four datalog channels as they are each long integers and each require two modbus&lt;a href=&quot;/ws/glossary#term49&quot; title=&quot;Modbus: • MODBUS Request,
A MODBUS Request is the message sent on the network by the Client to initiate a
transaction,
• MODBUS Confirmation,
A MODBUS Confirmation is the Response Message received on the Client side
• MODBUS Indication,
A MODBUS Indication is the Request message received on the Server side,
• MODBUS Response
A MODBUS Response is the Response message sent by the Server,


The MODBUS messaging services (Client / Server Model) are used for real time information exchange:

• between two device applications,

• between device application and other device,

• between HMI/SCADA applications and devices,

• between a PC and a device program providing on line services.


See:

MODBUS Application Protocol Specification V1.1a.

RFC 1122 Requirements for Internet Hosts -- Communication Layers&quot; class=&quot;glossary-indicator&quot;&gt;i&lt;/a&gt; addresses.
&lt;/P&gt;
&lt;P&gt;
Alternatively, up to 20 channels may be data logged in each record. The CubeIP is then able to store some 5,500 records.
&lt;/P&gt;
&lt;P&gt;
If the CubeIP is configured to log kwh and kvarh every 30 minutes then records spanning more than one year will be stored. Records are maintained in a cicular recording which means that the oldest records will be overwritten when the recording is full.
&lt;/P&gt;
 &lt;p&gt;&lt;a href=&quot;http://www.802automation.com/ws/Data_Logging_memory&quot;&gt;read more&lt;/a&gt;&lt;/p&gt;</description>
 <comments>http://www.802automation.com/ws/Data_Logging_memory#comment</comments>
 <category domain="http://www.802automation.com/ws/taxonomy/term/35">802anonymous</category>
 <pubDate>Thu, 16 Oct 2008 14:10:58 +0100</pubDate>
 <dc:creator>Paul</dc:creator>
 <guid isPermaLink="false">123 at http://www.802automation.com/ws</guid>
</item>
<item>
 <title>CubeIP - Backing up files</title>
 <link>http://www.802automation.com/ws/Backing_up_files</link>
 <description> &lt;H2&gt;CubeIP - Backing up files&lt;/H2&gt;

The code snippets shown below are for demonstration purposes only and should only be used by qualified personnel. (Microsoft Windows Vista - see note below.)

&lt;p&gt;
The CubeIP contains four files which determine the pages shown on the Web pages and the data sent over ftp and shown in the Energy Profile.
&lt;/p&gt;

&lt;pre&gt;
       dir.txt         a directory listing      read only
       clone.icf       the IP configuration     read/write
       log.csv         the entire datalog file  read only
       webpages.fat    all the individual       read/write
                       webpages as one file
&lt;/pre&gt;

Access to the files is through tftp&lt;a href=&quot;/ws/glossary#term57&quot; title=&quot;tftp: Trivial File Transfer Protocol (TFTP) is a very simple file transfer protocol, 
  with the functionality of a very basic form of FTP; it was first defined in 
  1980.
 Some details of TFTP: 
 * It uses UDP (port 69) as its transport protocol (unlike FTP which uses TCP 
  port 21).
  * It cannot list directory contents.
  * It has no authentication or encryption mechanisms.
  * It is used to read files from, or write files to, a remote server.
  * It supports three different transfer modes, &amp;amp;quot;netascii&amp;amp;quot;, &amp;amp;quot;octet&amp;amp;quot; 
  and &amp;amp;quot;mail&amp;amp;quot;, with the first two corresponding to the &amp;amp;quot;ASCII&amp;amp;quot; 
  and &amp;amp;quot;image&amp;amp;quot; (binary) modes of the FTP protocol; the third is now obsolete 
  and is hardly ever used.
  * It has a file size limit of 32 MB.
Due to the lack of security, it is dangerous over the open Internet. Thus, 
  TFTP is generally only used on private, local networks.
Example command in tftp in Windows Transfers files to and from a remote 
  computer running the TFTP service.
TFTP [-i] host [GET | PUT] source [destination]
 -i Specifies binary image transfer mode (also called octet). 
  In binary image mode the file is moved literally, byte by byte. Use this mode 
  when transferring binary files.
  host Specifies the local or remote host.
  GET Transfers the file destination on the remote host to the 
  file source on the local host.
  PUT Transfers the file source on the local host to the file 
  destination on the remote host.
  source Specifies the file to transfer.
  destination Specifies where to transfer the file.

&quot; class=&quot;glossary-indicator&quot;&gt;i&lt;/a&gt; and a command can be carried out by creating a single line file with a .bat extension. Vista users will have to ensure that the tftp, which is always included as a standard feature, is enabled.

&lt;pre&gt;
tftp -i 192.168.1.127 GET dir.txt dir.txt 
&lt;/PRE&gt;

This will GET the clone file from a CubeIP with an IP address of 192.168.1.127 and create a read only file in the same directory called clone.icf. (Tftp uses port 69 so can normally only be used locally thus preventing any unauthorised remote access to these files. The port can be deliberately opened with port forwarding or a DMZ.) 

Adding pause to the file then enables you to check that the command completed successfully before acknowledging it and closing the command window.

&lt;pre&gt;
tftp -i 192.168.1.127 GET dir.txt dir.txt 
pause
&lt;/PRE&gt;

All four files can be saved by including the four tftp GET commands in one file.

&lt;pre&gt;
tftp -i 192.168.1.127 GET dir.txt dir.txt 
tftp -i 192.168.1.127 GET log.csv log.csv
tftp -i 192.168.1.127 GET webpages.fat webpages.fat
tftp -i 192.168.1.127 GET clone.icf clone.icf
pause
&lt;/PRE&gt;

As the files are read only this will not normally overwrite earlier files.


&lt;H3&gt;Advanced&lt;/H3&gt;

The sample code shown below creates file names which include the IP address and the local time and date. This enables better records to be maintained and files are unlikely to be overwritten.

&lt;pre&gt;

set WP_defaultIP=192.168.1.127

for /F &quot;tokens=1-4 delims=/:., &quot; %%a in (&#039;date/T&#039;) do set f_name=%%c%%b%%a
for /F &quot;tokens=1-2 delims=:., &quot; %%a in (&#039;time/T&#039;) do set f_name=%f_name%_%%a%%b
tftp -i %WP_defaultIP% GET dir.txt __%WP_defaultIP%_%f_name%_dir.txt 
rem notepad __%WP_defaultIP%_%f_name%_dir.txt  


for /F &quot;tokens=1-4 delims=/:., &quot; %%a in (&#039;date/T&#039;) do set f_name=%%c%%b%%a
for /F &quot;tokens=1-2 delims=:., &quot; %%a in (&#039;time/T&#039;) do set f_name=%f_name%_%%a%%b
tftp -i %WP_defaultIP% GET clone.icf __%WP_defaultIP%_%f_name%_clone.icf
copy  __%WP_defaultIP%_%f_name%_clone.icf __%WP_defaultIP%_clone.icf
rem notepad __%WP_defaultIP%_%f_name%_clone.icf  

for /F &quot;tokens=1-4 delims=/:., &quot; %%a in (&#039;date/T&#039;) do set f_name=%%c%%b%%a
for /F &quot;tokens=1-2 delims=:., &quot; %%a in (&#039;time/T&#039;) do set f_name=%f_name%_%%a%%b
tftp -i %WP_defaultIP% GET log.csv __%WP_defaultIP%_%f_name%_log.csv 
rem notepad __%WP_defaultIP%_%f_name%_log.csv  

for /F &quot;tokens=1-4 delims=/:., &quot; %%a in (&#039;date/T&#039;) do set f_name=%%c%%b%%a
for /F &quot;tokens=1-2 delims=:., &quot; %%a in (&#039;time/T&#039;) do set f_name=%f_name%_%%a%%b
tftp -i %WP_defaultIP% GET webpages.fat __%WP_defaultIP%_%f_name%_webpages.fat 
rem notepad __%WP_defaultIP%_%f_name%_webpages.fat  

pause

&lt;/pre&gt;

&lt;p&gt;
Note.
&lt;BR&gt;
Microsoft Windows Vista.
&lt;BR&gt;
tftp may need to be enabled - see http://windowshelp.microsoft.com/Windows/en-US/Help/1e62706b-ef53-4ecd-a217-0e7bcf82009b1033.mspx 
&lt;/p&gt; </description>
 <comments>http://www.802automation.com/ws/Backing_up_files#comment</comments>
 <category domain="http://www.802automation.com/ws/taxonomy/term/35">802anonymous</category>
 <pubDate>Fri, 10 Oct 2008 10:57:51 +0100</pubDate>
 <dc:creator>Paul</dc:creator>
 <guid isPermaLink="false">122 at http://www.802automation.com/ws</guid>
</item>
<item>
 <title>CubeIP -  Carbon emission factors</title>
 <link>http://www.802automation.com/ws/Carbon_emission_factors</link>
 <description> &lt;H3&gt;Carbon emission factors&lt;/H3&gt;
This information is correct at the time of writing but is subject to regulatory revision and should not be relied upon.
&lt;BR&gt;
&lt;BR&gt;
The factors given below are from Annex A of UKETS(01)05 (Guidelines for the measurement and reporting of emissions in the UK Emissions Trading Scheme). These figures are consistent with the National Air Emission Inventory and with the carbon factors given in the generic PP3.02 (Underlying Climate Change Agreement for the [ ] sector). 
&lt;BR&gt;&lt;BR&gt;
&lt;PRE&gt;
Carbon emission factors 
Fuel                          kg C/kWh    kg C02/kWh  
 &lt;p&gt;&lt;a href=&quot;http://www.802automation.com/ws/Carbon_emission_factors&quot;&gt;read more&lt;/a&gt;&lt;/p&gt;</description>
 <comments>http://www.802automation.com/ws/Carbon_emission_factors#comment</comments>
 <category domain="http://www.802automation.com/ws/taxonomy/term/35">802anonymous</category>
 <pubDate>Wed, 08 Oct 2008 11:52:47 +0100</pubDate>
 <dc:creator>Paul</dc:creator>
 <guid isPermaLink="false">121 at http://www.802automation.com/ws</guid>
</item>
<item>
 <title>CubeIP - Display scaling</title>
 <link>http://www.802automation.com/ws/Display_scaling</link>
 <description> &lt;pre&gt;
&lt;strong&gt;2.7 Display Scaling&lt;/strong&gt;
Measured values displayed on the LCD are scaled by 
the user settings of CT and/or
PT primaries to provide optimum resolution.

&lt;strong&gt;2.7.1 Voltage Scaling)&lt;/strong&gt;
PT 	Setting                  Resolution
10V&lt;sub&gt;L-L&lt;/sub&gt; - 80V&lt;sub&gt;L-L&lt;/sub&gt;                 0.01 V
81V&lt;sub&gt;L-L&lt;/sub&gt; - 800V&lt;sub&gt;L-L&lt;/sub&gt;                0.1 V
801V&lt;sub&gt;L-L&lt;/sub&gt; - 8,000V&lt;sub&gt;L-L&lt;/sub&gt;             1 V
8,001V&lt;sub&gt;L-L&lt;/sub&gt; - 80,000V&lt;sub&gt;L-L&lt;/sub&gt;          0.01 kV
80,001V&lt;sub&gt;L-L&lt;/sub&gt; - 440,000V&lt;sub&gt;L-L&lt;/sub&gt;        0.1 kV

&lt;strong&gt;2.7.2 Current Scaling&lt;/strong&gt;
 &lt;p&gt;&lt;a href=&quot;http://www.802automation.com/ws/Display_scaling&quot;&gt;read more&lt;/a&gt;&lt;/p&gt;</description>
 <comments>http://www.802automation.com/ws/Display_scaling#comment</comments>
 <category domain="http://www.802automation.com/ws/taxonomy/term/35">802anonymous</category>
 <pubDate>Wed, 08 Oct 2008 11:32:43 +0100</pubDate>
 <dc:creator>Paul</dc:creator>
 <guid isPermaLink="false">120 at http://www.802automation.com/ws</guid>
</item>
<item>
 <title>CubeIP - Configuration save and restore</title>
 <link>http://www.802automation.com/ws/node/119</link>
 <description> &lt;h2&gt;NC300 Configuration Save and Restore&lt;/h2&gt;
&lt;p&gt;
The full configuration can be downloaded as a text file, clone.icf, from the NC300 by using tftp&lt;a href=&quot;/ws/glossary#term57&quot; title=&quot;tftp: Trivial File Transfer Protocol (TFTP) is a very simple file transfer protocol, 
  with the functionality of a very basic form of FTP; it was first defined in 
  1980.
 Some details of TFTP: 
 * It uses UDP (port 69) as its transport protocol (unlike FTP which uses TCP 
  port 21).
  * It cannot list directory contents.
  * It has no authentication or encryption mechanisms.
  * It is used to read files from, or write files to, a remote server.
  * It supports three different transfer modes, &amp;amp;quot;netascii&amp;amp;quot;, &amp;amp;quot;octet&amp;amp;quot; 
  and &amp;amp;quot;mail&amp;amp;quot;, with the first two corresponding to the &amp;amp;quot;ASCII&amp;amp;quot; 
  and &amp;amp;quot;image&amp;amp;quot; (binary) modes of the FTP protocol; the third is now obsolete 
  and is hardly ever used.
  * It has a file size limit of 32 MB.
Due to the lack of security, it is dangerous over the open Internet. Thus, 
  TFTP is generally only used on private, local networks.
Example command in tftp in Windows Transfers files to and from a remote 
  computer running the TFTP service.
TFTP [-i] host [GET | PUT] source [destination]
 -i Specifies binary image transfer mode (also called octet). 
  In binary image mode the file is moved literally, byte by byte. Use this mode 
  when transferring binary files.
  host Specifies the local or remote host.
  GET Transfers the file destination on the remote host to the 
  file source on the local host.
  PUT Transfers the file source on the local host to the file 
  destination on the remote host.
  source Specifies the file to transfer.
  destination Specifies where to transfer the file.

&quot; class=&quot;glossary-indicator&quot;&gt;i&lt;/a&gt;. 
&lt;/p&gt;
&lt;br&gt;
For example, replace 192.168.2.45 with the correct address for the NC300.
&lt;/p&gt;
&lt;pre&gt;
tftp -i 192.168.2.45 GET clone.icf
&lt;/pre&gt;
&lt;p&gt;
The file contains a list of addresses and their corresponding settings. The file can be edited with a simple editor such as Wordpad but this is not recommended as the file may be rendered useless if any erroneous values are entered.
&lt;/p&gt;
&lt;p&gt;
The NC300 configuration file should be kept in a secure location to provide a backup of the configuration and form part of any future audit.
&lt;/p&gt; &lt;p&gt;&lt;a href=&quot;http://www.802automation.com/ws/node/119&quot;&gt;read more&lt;/a&gt;&lt;/p&gt;</description>
 <comments>http://www.802automation.com/ws/node/119#comment</comments>
 <category domain="http://www.802automation.com/ws/taxonomy/term/35">802anonymous</category>
 <pubDate>Mon, 29 Sep 2008 12:50:27 +0100</pubDate>
 <dc:creator>Paul</dc:creator>
 <guid isPermaLink="false">119 at http://www.802automation.com/ws</guid>
</item>
<item>
 <title>CubeIP - Variables in WebPages and datalogs</title>
 <link>http://www.802automation.com/ws/node/118</link>
 <description>&lt;html xmlns:o=&quot;urn:schemas-microsoft-com:office:office&quot;
xmlns:x=&quot;urn:schemas-microsoft-com:office:excel&quot;
xmlns=&quot;http://www.w3.org/TR/REC-html40&quot;&gt;

&lt;head&gt;
&lt;meta http-equiv=Content-Type content=&quot;text/html; charset=windows-1252&quot;&gt;
&lt;meta name=ProgId content=Excel.Sheet&gt;
&lt;meta name=Generator content=&quot;Microsoft Excel 10&quot;&gt;
&lt;link rel=File-List href=&quot;Page_files/filelist.xml&quot;&gt;
&lt;style id=&quot;CubeIP_Modbus_10all_3099_Styles&quot;&gt;
&lt;!--table
	{mso-displayed-decimal-separator:&quot;\.&quot;;
	mso-displayed-thousand-separator:&quot;\,&quot;;}
.xl243099
	{padding-top:1px;
	padding-right:1px;
	padding-left:1px;
	mso-ignore:padding;
	color:windowtext;
	font-size:10.0pt;
	font-weight:400;
	font-style:normal;
	text-decoration:none;
	font-family:Arial;
	mso-generic-font-family:auto;
	mso-font-charset:0;
	mso-number-format:General;
	text-align:general;
	vertical-align:bottom;
	mso-background-source:auto;
	mso-pattern:auto;
	white-space:normal;}
.xl253099
	{padding-top:1px;
	padding-right:1px;
	padding-left:1px;
	mso-ignore:padding;
	color:windowtext;
	font-size:10.0pt;
	font-weight:400;
	font-style:normal;
	text-decoration:none;
	font-family:Arial;
	mso-generic-font-family:auto;
	mso-font-charset:0;
	mso-number-format:0;
	text-align:center;
	vertical-align:bottom;
	mso-background-source:auto;
	mso-pattern:auto;
	white-space:normal;}
.xl263099
	{padding-top:1px;
	padding-right:1px;
	padding-left:1px;
	mso-ignore:padding;
	color:windowtext;
	font-size:10.0pt;
	font-weight:400;
	font-style:normal;
	text-decoration:none;
	font-family:Arial;
	mso-generic-font-family:auto;
	mso-font-charset:0;
	mso-number-format:General;
	text-align:center;
	vertical-align:bottom;
	mso-background-source:auto;
	mso-pattern:auto;
	white-space:normal;}
.xl273099
	{padding-top:1px;
	padding-right:1px;
	padding-left:1px;
	mso-ignore:padding;
	color:windowtext;
	font-size:10.0pt;
	font-weight:700;
	font-style:normal;
	text-decoration:none;
	font-family:Arial, sans-serif;
	mso-font-charset:0;
	mso-number-format:General;
	text-align:general;
	vertical-align:bottom;
	mso-background-source:auto;
	mso-pattern:auto;
	white-space:normal;}
--&gt;
&lt;/style&gt;
&lt;/head&gt;

&lt;body&gt;
&lt;!--[if !excel]&gt;&amp;nbsp;&amp;nbsp;&lt;![endif]--&gt;
&lt;!--The following information was generated by Microsoft Excel&#039;s Publish as Web
Page wizard.--&gt;
&lt;!--If the same item is republished from Excel, all information between the DIV
tags will be replaced.--&gt;
&lt;!-----------------------------&gt;
&lt;!--START OF OUTPUT FROM EXCEL PUBLISH AS WEB PAGE WIZARD --&gt;
&lt;!-----------------------------&gt;

&lt;div id=&quot;CubeIP_Modbus_10all_3099&quot; align=center x:publishsource=&quot;Excel&quot;&gt;

&lt;table x:str border=0 cellpadding=0 cellspacing=0 width=517 class=xl243099
 style=&#039;border-collapse:collapse;table-layout:fixed;width:388pt&#039;&gt;
 &lt;col class=xl273099 width=155 style=&#039;mso-width-source:userset;mso-width-alt:
 5668;width:116pt&#039;&gt;
 &lt;col class=xl243099 width=255 style=&#039;mso-width-source:userset;mso-width-alt:
 9325;width:191pt&#039;&gt;
 &lt;col class=xl263099 width=53 style=&#039;mso-width-source:userset;mso-width-alt:
 1938;width:40pt&#039;&gt;
 &lt;col class=xl253099 width=54 style=&#039;mso-width-source:userset;mso-width-alt:
 1974;width:41pt&#039;&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;HEX&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;Decimal&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;b&gt;Network
  Settings&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;b&gt;IP
  address&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;IP Address 1&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07F2&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2034&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;IP Address 2&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07F3&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2035&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;IP Address 3&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07F4&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2036&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;IP Address 4&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07F5&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2037&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;IP Address 5&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07F6&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2038&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;IP Address 6&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07F7&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2039&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;b&gt;Subnet&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Subnet Address 1&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07F8&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2040&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Subnet Address 2&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07F9&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2041&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Subnet Address 3&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07FA&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2042&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Subnet Address 4&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07FB&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2043&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;b&gt;Gateway&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Gateway Address 1&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07FC&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2044&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Gateway Address 1&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07FD&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2045&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Gateway Address 1&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07FE&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2046&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Gateway Address 1&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07FF&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2047&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;b&gt;Primary
  DNS&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Primary Address 1&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07E8&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2024&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Primary Address 2&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07E9&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2025&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Primary Address 3&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07EA&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2026&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Primary Address 4&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07EB&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2027&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;b&gt;Secondary
  DNS&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Secondary Address 1&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07E4&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2020&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Secondary Address 2&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07E5&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2021&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Secondary Address 3&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07E6&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2022&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Secondary Address 4&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07E7&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2023&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;b&gt;MAC
  address&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;MAC Address 1&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07EC&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2028&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;MAC Address 2&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07ED&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2029&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;MAC Address 3&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07EE&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2030&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;MAC Address 4&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07EF&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2031&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;MAC Address 5&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07F0&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2032&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;MAC Address 6&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07F1&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2033&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;b&gt;Datalogging&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Datalog Enable&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0743&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1859&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=34 valign=bottom style=&#039;height:25.5pt&#039;&gt;
  &lt;td height=34 class=xl273099 width=155 style=&#039;height:25.5pt;width:116pt&#039;&gt;&lt;b&gt;Datalog
  Parameters&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Number of parameters to log&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0739&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1849&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 1&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0745&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1861&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 2&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0748&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1864&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 3&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x074B&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1867&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 4&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x074E&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1870&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 5&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0751&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1873&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 6&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0754&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1876&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 7&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0757&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1879&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 8&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x075A&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1882&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 9&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x075D&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1885&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 10&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0760&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1888&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;page-break-before:always;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 11&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0763&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1891&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 12&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0766&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1894&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 13&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0769&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1897&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 14&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x076C&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1900&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 15&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x076F&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1903&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 16&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0772&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1906&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 17&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0775&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1909&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 18&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0778&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1912&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 19&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x077B&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1915&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Channel 20&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x077E&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1918&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Datalog Period (seconds)&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0780&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1920&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=34 valign=bottom style=&#039;height:25.5pt&#039;&gt;
  &lt;td height=34 class=xl273099 width=155 style=&#039;height:25.5pt;width:116pt&#039;&gt;&lt;b&gt;Datalog
  FTP server credentials&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;FTP URL&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0740&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1856&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;FTP username&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0741&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1857&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;FTP server Password&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0742&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1858&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;FTP send interval minutes&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x073F&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1855&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=68 valign=bottom style=&#039;height:51.0pt&#039;&gt;
  &lt;td height=68 class=xl273099 width=155 style=&#039;height:51.0pt;width:116pt&#039;&gt;&lt;b&gt;FTP
  server IP address - &lt;br&gt;
    only used if a url is not entered&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;FTP server IP Address 1&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0781&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1921&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;FTP server IP Address 2&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0782&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1922&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;FTP server IP Address 3&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0783&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1923&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;FTP server IP Address 4&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0784&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1924&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;b&gt;Custom
  File Format&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0738&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1848&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;b&gt;Profile
  Settings&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Oldest Record date in the
  datalog UITC&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x073A&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1850&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Newest Record date in the
  datalog UITC&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x073B&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1851&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Profile report date from
  date (history.log)&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x073C&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1852&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Profile report time
  resolution&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x073D&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1853&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Profile number of records to
  report&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x073E&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1854&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;b&gt;Graph
  Scales&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Left vertical scaling (low)&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0700&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1792&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Left vertical scaling (high)&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0701&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1793&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Left vertical scaling
  (division spacing)&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0702&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1794&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Right vertical scaling (low)&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0703&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1795&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Right vertical scaling
  (high)&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0704&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1796&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Right vertical scaling
  (division spacing)&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0705&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1797&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=34 valign=bottom style=&#039;height:25.5pt&#039;&gt;
  &lt;td height=34 class=xl273099 width=155 style=&#039;height:25.5pt;width:116pt&#039;&gt;&lt;b&gt;Graph
  Parameters Logged&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Parameter 1 to log&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0706&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1798&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Scale (left or right) for
  parameter 1&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0707&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1799&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Parameter 2 to log&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0708&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1800&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Scale (left or right) for
  parameter 2&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0709&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1801&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Parameter 3 to log&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x070A&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1802&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Scale (left or right) for
  parameter 3&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x070B&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1803&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Parameter 4 to log&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x070C&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1804&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Scale (left or right) for
  parameter 4&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x070D&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1805&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Chart speed tba&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x070E&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1806&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Acquisition rate (seconds)&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x070F&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1807&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Config changed - used to
  update settings&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0710&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1808&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;b&gt;Graph
  indirection&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=34 valign=bottom style=&#039;height:25.5pt&#039;&gt;
  &lt;td height=34 class=xl273099 width=155 style=&#039;height:25.5pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Read from address pointed to
  by GRAPH_PARAMETER1&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0711&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1809&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=34 valign=bottom style=&#039;height:25.5pt&#039;&gt;
  &lt;td height=34 class=xl273099 width=155 style=&#039;height:25.5pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Read from address pointed to
  by GRAPH_PARAMETER2&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0712&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1810&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=34 valign=bottom style=&#039;height:25.5pt&#039;&gt;
  &lt;td height=34 class=xl273099 width=155 style=&#039;height:25.5pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Read from address pointed to
  by GRAPH_PARAMETER3&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0713&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1811&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=34 valign=bottom style=&#039;height:25.5pt&#039;&gt;
  &lt;td height=34 class=xl273099 width=155 style=&#039;height:25.5pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Read from address pointed to
  by GRAPH_PARAMETER4&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0714&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1812&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;b&gt;Monthly
  Totals kWh&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;January&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0785&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1925&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;February&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0786&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1926&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;March&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0787&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1927&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;April&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0788&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1928&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;May&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0789&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1929&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;June&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x078A&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1930&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;July&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x078B&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1931&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;August&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x078C&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1932&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;September&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x078D&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1933&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;October&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x078E&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1934&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;November&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x078F&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1935&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;December&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0790&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1936&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Meter Name&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x0791&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;1937&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=34 valign=bottom style=&#039;height:25.5pt&#039;&gt;
  &lt;td height=34 class=xl273099 width=155 style=&#039;height:25.5pt;width:116pt&#039;&gt;&lt;b&gt;Simple
  Network Time Protocol&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;SNTP_TIMESTAMP&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07DA&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2010&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;SNTP_URL&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07DB&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2011&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;SNTP_IP1&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07DC&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2012&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;SNTP_IP2&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07DD&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2013&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;SNTP_IP3&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07DE&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2014&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;SNTP_IP4&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07DF&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2015&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;b&gt;System
  Settings&lt;/b&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl263099 width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl253099 width=54 style=&#039;width:41pt&#039; x:str=&quot;&quot;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;tr height=17 valign=bottom style=&#039;height:12.75pt&#039;&gt;
  &lt;td height=17 class=xl273099 width=155 style=&#039;height:12.75pt;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td class=xl243099 width=255 style=&#039;width:191pt&#039;&gt;Firmware Version&lt;/td&gt;
  &lt;td class=xl263099 align=center width=53 style=&#039;width:40pt&#039;&gt;0x07E0&lt;/td&gt;
  &lt;td class=xl253099 align=center width=54 style=&#039;width:41pt&#039;&gt;2016&lt;/td&gt;
 &lt;/tr&gt;
 &lt;![if supportMisalignedColumns]&gt;
 &lt;tr height=0 style=&#039;display:none&#039;&gt;
  &lt;td width=155 style=&#039;width:116pt&#039;&gt;&lt;/td&gt;
  &lt;td width=255 style=&#039;width:191pt&#039;&gt;&lt;/td&gt;
  &lt;td width=53 style=&#039;width:40pt&#039;&gt;&lt;/td&gt;
  &lt;td width=54 style=&#039;width:41pt&#039;&gt;&lt;/td&gt;
 &lt;/tr&gt;
 &lt;![endif]&gt;
&lt;/table&gt;

&lt;/div&gt;

&lt;p&gt;Correction&lt;/p&gt;&lt;p&gt;&lt;a href=&quot;http://www.802automation.com/ws/node/118&quot;&gt;read more&lt;/a&gt;&lt;/p&gt;</description>
 <comments>http://www.802automation.com/ws/node/118#comment</comments>
 <category domain="http://www.802automation.com/ws/taxonomy/term/35">802anonymous</category>
 <pubDate>Mon, 29 Sep 2008 10:41:40 +0100</pubDate>
 <dc:creator>Paul</dc:creator>
 <guid isPermaLink="false">118 at http://www.802automation.com/ws</guid>
</item>
</channel>
</rss>
